@@ -1,10 +1,11 @@
-import React, { FunctionComponent } from 'react';
+import React, { FunctionComponent, ReactNode } from 'react';
+import classNames from 'classnames';
 import { AppNotificationSeverity } from 'app/types';
 
 interface Props {
   title: string;
   icon?: string;
-  text?: string;
+  body?: ReactNode;
   severity: AppNotificationSeverity;
   onClose?: () => void;
 }
@@ -14,23 +15,30 @@ function getIconFromSeverity(severity: AppNotificationSeverity): string {
     case AppNotificationSeverity.Error: {
       return 'fa fa-exclamation-triangle';
     }
+    case AppNotificationSeverity.Warning: {
+      return 'fa fa-exclamation-triangle';
+    }
+    case AppNotificationSeverity.Info: {
+      return 'fa fa-info-circle';
+    }
     case AppNotificationSeverity.Success: {
       return 'fa fa-check';
     }
     default:
-      return null;
+      return '';
   }
 }
 
-export const AlertBox: FunctionComponent<Props> = ({ title, icon, text, severity, onClose }) => {
+export const AlertBox: FunctionComponent<Props> = ({ title, icon, body, severity, onClose }) => {
+  const alertClass = classNames('alert', `alert-${severity}`);
   return (
-    <div className={`alert alert-${severity}`}>
+    <div className={alertClass}>
       <div className="alert-icon">
         <i className={icon || getIconFromSeverity(severity)} />
       </div>
       <div className="alert-body">
         <div className="alert-title">{title}</div>
-        {text && <div className="alert-text">{text}</div>}
+        {body && <div className="alert-text">{body}</div>}
       </div>
       {onClose && (
         <button type="button" className="alert-close" onClick={onClose}>
